/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package zswzg.kex.tls;

import java.util.Vector;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.config.AttributeGroup;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * Klasse für die Speicherung der Informationen eines Konfigurationsobjektes vom Typ typ.anzeigeQuerschnittTypUmsetzungTls.
 *
 * @version $Revision: 1.1 $ / $Date: 2008/09/15 08:37:49 $ / ($Author: Drapp $)
 *
 * @author Dambach-Werke GmbH
 * @author Thomas Drapp
 *
 */
public class AnzeigeQuerschnittTypUmsetzungTls
{
  /**
   * DebugLogger für Debug-Ausgaben.
   */
  @SuppressWarnings("unused")
  private static Debug m_debug = Debug.getLogger();
  /**
   * Datenmodell.
   */
  protected DataModel m_dataModel;
  /**
   * Pid des Konfigurationsobjektes vom Typ typ.anzeigeQuerschnittTypUmsetzungTls.
   */
  protected String m_pid;
  /**
   * Konfigurationsobjekt vom Typ typ.anzeigeQuerschnittTypUmsetzung.
   */
  protected SystemObject m_anzeigeQuerschnittTypUmsetzung;
  /**
   * Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   */
  protected Vector<GlobalUmsetzung> m_listeGlobalUmsetzung = new Vector<GlobalUmsetzung>();
  /**
   * Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Helligkeit.
   */
  protected Vector<GlobalUmsetzung> m_listeUmsetzungHelligkeit = new Vector<GlobalUmsetzung>();
  /**
   * Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Betriebsart.
   */
  protected Vector<GlobalUmsetzung> m_listeUmsetzungBetriebsart = new Vector<GlobalUmsetzung>();
  /**
   * Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Passivierung.
   */
  protected Vector<GlobalUmsetzung> m_listeUmsetzungPassivierung = new Vector<GlobalUmsetzung>();
  /**
   * Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Schaltung.
   */
  protected Vector<GlobalUmsetzung> m_listeUmsetzungSchaltung = new Vector<GlobalUmsetzung>();

  /**
   * Konstruktor mit Übergabe des Daten-Modell, der Pid der AnzeigeQuerschnittTypUmsetzung und dem Konfigurationsobjekt vom Typ typ.anzeigeQuerschnittTypUmsetzung.
   * Die Umsetzungen werden in die entsprechenden Listen (Helligkeit, Betriebsart, Passivierung und Schaltung) und in die globale Liste eingetragen.
   *
   * @param dataModel Daten-Modell.
   * @param pid Pid der AnzeigeQuerschnittTypUmsetzung.
   * @param anzeigeQuerschnittTypUmsetzung Konfigurationsobjekt vom Typ typ.anzeigeQuerschnittTypUmsetzung.
   */
  public AnzeigeQuerschnittTypUmsetzungTls(DataModel dataModel, String pid, SystemObject anzeigeQuerschnittTypUmsetzung)
  {
    m_dataModel = dataModel;
    m_pid = pid;
    m_anzeigeQuerschnittTypUmsetzung = anzeigeQuerschnittTypUmsetzung;

    AttributeGroup atgAnzeigeQuerschnittTypUmsetzungTls = m_dataModel.getAttributeGroup("atg.anzeigeQuerschnittTypUmsetzungTls");

    Data datenAtgAnzeigeQuerschnittTypUmsetzungTls = anzeigeQuerschnittTypUmsetzung.getConfigurationData(atgAnzeigeQuerschnittTypUmsetzungTls);

    if (datenAtgAnzeigeQuerschnittTypUmsetzungTls != null)
    {
      int anzahlUmsetzungen = datenAtgAnzeigeQuerschnittTypUmsetzungTls.getArray("UmsetzungHelligkeit").getLength();

      for (int i = 0; i < anzahlUmsetzungen; i++)
      {
        GlobalUmsetzung globalUmsetzung = new GlobalUmsetzung(datenAtgAnzeigeQuerschnittTypUmsetzungTls.getArray("UmsetzungHelligkeit").getItem(i));

        m_listeUmsetzungHelligkeit.add(globalUmsetzung);
        m_listeGlobalUmsetzung.add(globalUmsetzung);
      }

      anzahlUmsetzungen = datenAtgAnzeigeQuerschnittTypUmsetzungTls.getArray("UmsetzungBetriebsart").getLength();

      for (int i = 0; i < anzahlUmsetzungen; i++)
      {
        GlobalUmsetzung globalUmsetzung = new GlobalUmsetzung(datenAtgAnzeigeQuerschnittTypUmsetzungTls.getArray("UmsetzungBetriebsart").getItem(i));

        m_listeUmsetzungBetriebsart.add(globalUmsetzung);
        m_listeGlobalUmsetzung.add(globalUmsetzung);
      }

      anzahlUmsetzungen = datenAtgAnzeigeQuerschnittTypUmsetzungTls.getArray("UmsetzungPassivierung").getLength();

      for (int i = 0; i < anzahlUmsetzungen; i++)
      {
        GlobalUmsetzung globalUmsetzung = new GlobalUmsetzung(datenAtgAnzeigeQuerschnittTypUmsetzungTls.getArray("UmsetzungPassivierung").getItem(i));

        m_listeUmsetzungPassivierung.add(globalUmsetzung);
        m_listeGlobalUmsetzung.add(globalUmsetzung);
      }

      anzahlUmsetzungen = datenAtgAnzeigeQuerschnittTypUmsetzungTls.getArray("UmsetzungSchaltung").getLength();

      for (int i = 0; i < anzahlUmsetzungen; i++)
      {
        GlobalUmsetzung globalUmsetzung = new GlobalUmsetzung(datenAtgAnzeigeQuerschnittTypUmsetzungTls.getArray("UmsetzungSchaltung").getItem(i));

        m_listeUmsetzungSchaltung.add(globalUmsetzung);
        m_listeGlobalUmsetzung.add(globalUmsetzung);
      }
    }
  }

  /**
   * Holen der Pid der AnzeigeQuerschnittTypUmsetzungTls.
   *
   * @return Pid der AnzeigeQuerschnittTypUmsetzungTls.
   */
  public String getPid()
  {
    return m_pid;
  }

  /**
   * Setzen der Pid der AnzeigeQuerschnittTypUmsetzungTls.
   *
   * @param pid Pid der AnzeigeQuerschnittTypUmsetzungTls.
   */
  public void setPid(String pid)
  {
    m_pid = pid;
  }

  /**
   * Holen des Konfigurationsobjektes vom Typ typ.anzeigeQuerschnittTypUmsetzung.
   *
   * @return Konfigurationsobjekt vom Typ typ.anzeigeQuerschnittTypUmsetzung.
   */
  public SystemObject getAnzeigeQuerschnittTypUmsetzung()
  {
    return m_anzeigeQuerschnittTypUmsetzung;
  }

  /**
   * Setzen des Konfigurationsobjektes vom Typ typ.anzeigeQuerschnittTypUmsetzung.
   *
   * @param anzeigeQuerschnittTypUmsetzung Konfigurationsobjekt vom Typ typ.anzeigeQuerschnittTypUmsetzung.
   */
  public void setAnzeigeQuerschnittTypUmsetzung(SystemObject anzeigeQuerschnittTypUmsetzung)
  {
    m_anzeigeQuerschnittTypUmsetzung = anzeigeQuerschnittTypUmsetzung;
  }

  /**
   * Holen des Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   *
   * @return Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   */
  public Vector<GlobalUmsetzung> getListeGlobalUmsetzung()
  {
    return m_listeGlobalUmsetzung;
  }

  /**
   * Setzen des Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   *
   * @param listeGlobalUmsetzung Vector mit Instanzen der Klasse GlobalUmsetzung mit allen Umsetzungen.
   */
  public void setListeGlobalUmsetzung(Vector<GlobalUmsetzung> listeGlobalUmsetzung)
  {
    m_listeGlobalUmsetzung = listeGlobalUmsetzung;
  }

  /**
   * Holen des Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Helligkeit.
   *
   * @return Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Helligkeit.
   */
  public Vector<GlobalUmsetzung> getListeUmsetzungHelligkeit()
  {
    return m_listeUmsetzungHelligkeit;
  }

  /**
   * Setzen des Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Helligkeit.
   *
   * @param listeUmsetzungHelligkeit Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Helligkeit.
   */
  public void setListeUmsetzungHelligkeit(Vector<GlobalUmsetzung> listeUmsetzungHelligkeit)
  {
    m_listeUmsetzungHelligkeit = listeUmsetzungHelligkeit;
  }

  /**
   * Holen des Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Betriebsart.
   *
   * @return Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Betriebsart.
   */
  public Vector<GlobalUmsetzung> getListeUmsetzungBetriebsart()
  {
    return m_listeUmsetzungBetriebsart;
  }

  /**
   * Setzen des Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Betriebsart.
   *
   * @param listeUmsetzungBetriebsart Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Betriebsart.
   */
  public void setListeUmsetzungBetriebsart(Vector<GlobalUmsetzung> listeUmsetzungBetriebsart)
  {
    m_listeUmsetzungBetriebsart = listeUmsetzungBetriebsart;
  }

  /**
   * Holen des Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Passivierung.
   *
   * @return Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Passivierung.
   */
  public Vector<GlobalUmsetzung> getListeUmsetzungPassivierung()
  {
    return m_listeUmsetzungPassivierung;
  }

  /**
   * Setzen des Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Passivierung.
   *
   * @param listeUmsetzungPassivierung Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Passivierung.
   */
  public void setListeUmsetzungPassivierung(Vector<GlobalUmsetzung> listeUmsetzungPassivierung)
  {
    m_listeUmsetzungPassivierung = listeUmsetzungPassivierung;
  }

  /**
   * Holen des Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Schaltung.
   *
   * @return Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Schaltung.
   */
  public Vector<GlobalUmsetzung> getListeUmsetzungSchaltung()
  {
    return m_listeUmsetzungSchaltung;
  }

  /**
   * Setzen des Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Schaltung.
   *
   * @param listeUmsetzungSchaltung Vector mit Instanzen der Klasse GlobalUmsetzung mit den Umsetzungen für die Schaltung.
   */
  public void setListeUmsetzungSchaltung(Vector<GlobalUmsetzung> listeUmsetzungSchaltung)
  {
    m_listeUmsetzungSchaltung = listeUmsetzungSchaltung;
  }
}
